@@ -55,6 +55,8 @@ enum {
         PROP_0,
         PROP_XML_NODE,
         PROP_XML_DOC,
+        PROP_UPNP_NAMESPACE,
+        PROP_DC_NAMESPACE,
         PROP_ID,
         PROP_PARENT_ID,
         PROP_RESTRICTED,
@@ -99,6 +101,12 @@ gupnp_didl_lite_object_set_property (GObject      *object,
         case PROP_XML_DOC:
                 didl_object->priv->xml_doc = g_value_dup_object (value);
                 break;
+        case PROP_UPNP_NAMESPACE:
+                didl_object->priv->upnp_ns = g_value_get_pointer (value);
+                break;
+        case PROP_DC_NAMESPACE:
+                didl_object->priv->dc_ns = g_value_get_pointer (value);
+                break;
         case PROP_ID:
                 gupnp_didl_lite_object_set_id (didl_object,
                                                g_value_get_string (value));
@@ -195,6 +203,18 @@ gupnp_didl_lite_object_get_property (GObject    *object,
                         (value,
                          gupnp_didl_lite_object_get_xml_node (didl_object));
                 break;
+        case PROP_UPNP_NAMESPACE:
+                g_value_set_pointer
+                        (value,
+                         gupnp_didl_lite_object_get_upnp_namespace
+                                (didl_object));
+                break;
+        case PROP_DC_NAMESPACE:
+                g_value_set_pointer
+                        (value,
+                         gupnp_didl_lite_object_get_dc_namespace
+                                (didl_object));
+                break;
         case PROP_ID:
                 g_value_set_string
                         (value,
@@ -276,35 +296,6 @@ gupnp_didl_lite_object_get_property (GObject    *object,
         }
 }
 
-static void
-gupnp_didl_lite_object_constructed (GObject *object)
-{
-        GObjectClass               *object_class;
-        GUPnPDIDLLiteObjectPrivate *priv;
-        xmlNs                     **ns_list;
-        short                       i;
-
-        priv = GUPNP_DIDL_LITE_OBJECT (object)->priv;
-
-        ns_list = xmlGetNsList (priv->xml_doc->doc,
-                                xmlDocGetRootElement (priv->xml_doc->doc));
-        for (i = 0; ns_list[i] != NULL; i++) {
-                if (ns_list[i]->prefix == NULL)
-                        continue;
-
-                if (g_ascii_strcasecmp ((char *) ns_list[i]->prefix,
-                                        (char *) "upnp") == 0)
-                        priv->upnp_ns = ns_list[i];
-                else if (g_ascii_strcasecmp ((char *) ns_list[i]->prefix,
-                                             (char *) "dc") == 0)
-                        priv->dc_ns = ns_list[i];
-        }
-
-        object_class = G_OBJECT_CLASS (gupnp_didl_lite_object_parent_class);
-        if (object_class->constructed != NULL)
-                object_class->constructed (object);
-}
-
 static void
 gupnp_didl_lite_object_dispose (GObject *object)
 {
@@ -331,7 +322,6 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
 
         object_class->set_property = gupnp_didl_lite_object_set_property;
         object_class->get_property = gupnp_didl_lite_object_get_property;
-        object_class->constructed = gupnp_didl_lite_object_constructed;
         object_class->dispose = gupnp_didl_lite_object_dispose;
 
         g_type_class_add_private (klass, sizeof (GUPnPDIDLLiteObjectPrivate));
@@ -378,6 +368,47 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
                                       G_PARAM_STATIC_NICK |
                                       G_PARAM_STATIC_BLURB));
 
+        /**
+         * GUPnPDIDLLiteObject:upnp-namespace
+         *
+         * Pointer to the UPnP namespace registered with the XML document                * containing this object.
+         *
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_UPNP_NAMESPACE,
+                 g_param_spec_pointer ("upnp-namespace",
+                                       "XML namespace",
+                                       "Pointer to the UPnP XML namespace "
+                                       "registered with the XML document "
+                                       "containing this object.",
+                                       G_PARAM_READWRITE |
+                                       G_PARAM_CONSTRUCT_ONLY |
+                                       G_PARAM_STATIC_NAME |
+                                       G_PARAM_STATIC_NICK |
+                                       G_PARAM_STATIC_BLURB));
+
+        /**
+         * GUPnPDIDLLiteObject:dc-namespace
+         *
+         * Pointer to the DublinCore namespace registered with the XML document
+         * containing this object.
+         *
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_DC_NAMESPACE,
+                 g_param_spec_pointer ("dc-namespace",
+                                       "XML namespace",
+                                       "Pointer to the Dublin Core XML "
+                                       "namespace registered with the XML "
+                                       "document containing this object.",
+                                       G_PARAM_READWRITE |
+                                       G_PARAM_CONSTRUCT_ONLY |
+                                       G_PARAM_STATIC_NAME |
+                                       G_PARAM_STATIC_NICK |
+                                       G_PARAM_STATIC_BLURB));
+
         /**
          * GUPnPDIDLLiteObject:id
          *
@@ -709,6 +740,8 @@ get_contributor_list_by_name (GUPnPDIDLLiteObject *object,
  * gupnp_didl_lite_object_new_from_xml:
  * @xml_node: The pointer to 'res' node in XML document
  * @xml_doc: The reference to XML document containing this object
+ * @upnp_ns: The pointer to 'upnp' namespace in XML document
+ * @dc_ns: The pointer to 'dc' namespace in XML document
  *
  * Creates a new #GUPnPDIDLLiteObject for the @xml_node.
  *
@@ -716,21 +749,28 @@ get_contributor_list_by_name (GUPnPDIDLLiteObject *object,
  **/
 GUPnPDIDLLiteObject *
 gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
-                                     GUPnPXMLDoc *xml_doc)
+                                     GUPnPXMLDoc *xml_doc,
+                                     xmlNs       *upnp_ns,
+                                     xmlNs       *dc_ns)
 {
         g_return_val_if_fail (xml_node != NULL, NULL);
         g_return_val_if_fail (xml_node->name != NULL, NULL);
-        g_return_val_if_fail (GUPNP_IS_XML_DOC (xml_doc), NULL);
+        g_return_val_if_fail (upnp_ns != NULL, NULL);
+        g_return_val_if_fail (dc_ns != NULL, NULL);
 
         if (g_ascii_strcasecmp ((char *) xml_node->name, "container") == 0)
                 return g_object_new (GUPNP_TYPE_DIDL_LITE_CONTAINER,
                                      "xml-node", xml_node,
                                      "xml-doc", xml_doc,
+                                     "upnp-namespace", upnp_ns,
+                                     "dc-namespace", dc_ns,
                                      NULL);
         else if (g_ascii_strcasecmp ((char *) xml_node->name, "item") == 0)
                 return g_object_new (GUPNP_TYPE_DIDL_LITE_ITEM,
                                      "xml-node", xml_node,
                                      "xml-doc", xml_doc,
+                                     "upnp-namespace", upnp_ns,
+                                     "dc-namespace", dc_ns,
                                      NULL);
         else
                 return NULL;
@@ -752,6 +792,39 @@ gupnp_didl_lite_object_get_xml_node (GUPnPDIDLLiteObject *object)
         return object->priv->xml_node;
 }
 
+/**
+ * gupnp_didl_lite_object_get_upnp_namespace:
+ * @object: The #GUPnPDIDLLiteObject
+ *
+ * Get the pointer to the UPnP namespace registered with the XML document.
+ *
+ * Return value: The pointer to UPnP namespace in XML document.
+ **/
+xmlNsPtr
+gupnp_didl_lite_object_get_upnp_namespace (GUPnPDIDLLiteObject *object)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
+
+        return object->priv->upnp_ns;
+}
+
+/**
+ * gupnp_didl_lite_object_get_dc_namespace:
+ * @object: The #GUPnPDIDLLiteObject
+ *
+ * Get the pointer to the DublinCore namespace registered with the XML document
+ * containing this object.
+ *
+ * Return value: The pointer to DublinCore namespace in XML document.
+ **/
+xmlNsPtr
+gupnp_didl_lite_object_get_dc_namespace (GUPnPDIDLLiteObject *object)
+{
+        g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
+
+        return object->priv->dc_ns;
+}
+
 /**
  * gupnp_didl_lite_object_get_upnp_class:
  * @object: The #GUPnPDIDLLiteObject
